pub fn build_gridfm_batch(
snapshots: &[GridfmSnapshot<'_>],
opts: &GridfmOptions,
) -> Result<GridfmDataset>Expand description
Build one GridFM artifact inventory for a batch of numbered snapshots.
pub fn build_gridfm_batch(
snapshots: &[GridfmSnapshot<'_>],
opts: &GridfmOptions,
) -> Result<GridfmDataset>Build one GridFM artifact inventory for a batch of numbered snapshots.