GridfmDataset

Struct GridfmDataset 

#[non_exhaustive]
pub struct GridfmDataset { pub artifacts: Vec<MemoryArtifact>, pub diagnostics: Vec<Diagnostic>, pub dropped_zero_impedance: usize, pub degenerate_cost_gens: usize, pub missing_cost_gens: usize, pub unsupported_cost_gens: usize, pub synthesized_gen_costs: usize, pub patched_gen_costs: usize, }
A complete GridFM directory ready for one powerio_core::Destination.

Artifact names are relative to the requested output directory and begin with raw/. The counts state every field the GridFM profile could not carry without replacing it with a default.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
artifacts: Vec<MemoryArtifact>diagnostics: Vec<Diagnostic>dropped_zero_impedance: usizedegenerate_cost_gens: usizemissing_cost_gens: usizeunsupported_cost_gens: usizesynthesized_gen_costs: usizepatched_gen_costs: usize